@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-__version__ = '1.0.0'
+__version__ = '1.0.4'
 __author__ = 'vin8tech'
 
 import os
@@ -39,5 +39,7 @@ __all__ = [
     'Webull',
     'utils',
     'indicators',
+    'factory'
+    'strategies'
     'path'
 ]
