@@ -26,7 +26,8 @@ class Borg:
 
 
 class RiskAssessor(Borg):
-    def __init__(self, initial_capital=1000, max_trades=1, initial_margin=100, risk2reward=1.0, risk_per_trade=100):
+    def __init__(self, initial_capital=1000, max_trades=1, initial_margin=100,
+                 risk2reward=1.0, risk_per_trade=100, **kwargs):
         Borg.__init__(self)
 
         self.capital = initial_capital
@@ -45,6 +46,7 @@ class RiskAssessor(Borg):
             raise Exception("Capital is lower than available_margin")
 
         Bot().add_command_handler("report", self.availableMarginHandler, "Get report")
+        Bot().add_command_handler("reset-rms", self.reset, "Reset RMS values")
 
     def availableMarginHandler(self, update, context):
         msg = "```\n" \
@@ -66,6 +68,9 @@ class RiskAssessor(Borg):
         self.capital = self.initial_capital
         self.available_margin = self.initial_margin
         self.active_positions.clear()
+        self.pnl = 0
+        self.win_trades = 0
+        self.loss_trades = 0
 
     def _should_trade(self, entry_price, stop_loss, quantity=None):
         spread = abs(entry_price - stop_loss)
@@ -138,8 +143,10 @@ class RiskAssessor(Borg):
 
         pnl = position.pnl()
 
-        self.available_margin = round(self.available_margin + pnl, 2)
-        self.capital = self.capital + pnl
+        self.available_margin = round(self.available_margin + pnl, 2) if pnl > 0 else self.available_margin
+        # if pnl is -ve then it would already be subtracted when entering the trade.
+        self.capital = self.capital + (position.entry_price * position.quantity) + pnl
+        # reclaim the capital deployed in trade
         self.pnl += pnl
         if pnl > 0:
             self.win_trades += 1
